@@ -294,7 +294,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
  # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
  # For more info: https://github.com/yarnpkg/yarn/issues/683#issuecomment-346038525
-    yarn_cache=os.getenv('PWD','') + '/.yarn_cache'
+    yarn_cache=os.getenv('PWD','') + '@tmp/.yarn_cache'
     local('mkdir -p .yarn_cache')
     local('yarn config set cache-folder %s' % yarn_cache)
 
